@@ -307,7 +307,7 @@ my $cache_free_min = $no_cache ? 0 : $cache_stats{freemin};
 my $cache_diskfree = $cache_stats{freesum};
 
 #NorduGrid middleware
-my ($ngversion) = '3.0.0';
+my ($ngversion) = '3.0.1';
 
 #Globus Toolkit version
 #globuslocation/share/doc/VERSION
@@ -349,7 +349,7 @@ for my $controldir (keys %controldirs) {
 
     my $conf_file = $config{conf_file};
     unless (open GMJOBSOUTPUT, 
-        "$config{arc_location}/libexec/arc/gm-jobs -u 0 -c $conf_file -d $controldir 2>/dev/null |") {
+        "$config{arc_location}/libexec/arc/gm-jobs -c $conf_file -d $controldir 2>/dev/null |") {
         error("Error in executing gm-jobs")
     }
 
